@@ -444,6 +444,14 @@ plot(cut(Z, 5))
 plot(eval.im(sqrt(Z) - 3))
 plot(solutionset(abs(Z - 6) <= 1))
 
+data(cells)
+d <- distmap(cells, dimyx=256)
+W <- levelset(d, 0.06)
+nopa <- par(mfrow=c(1,2))
+plot(W)
+plot(connected(W))
+par(nopa)
+
 Z <- as.im(function(x,y) { 4 * x^2 + 3 * y }, letterR)
 plot(Z)
 plot(letterR, add=TRUE)
